from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

AUTHOR = "Verve"
VERSION = "0.0.4"
DESCRIPTION = "Simple interface for neural chatbots."

setup(
    name="neural_chat",
    version=VERSION,
    author=AUTHOR,
    author_email="<verve_is_god@protonmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=["numpy", "nltk", "tensorflow", "gtts", "pyttsx3"],
    keywords=["python", "neural", "machine learning", "chatbots",
              "chat", "artificial intelligence", "virtual assistant", "voice"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
    ]
)



__title__ = 'neural-chat'
__author__ = 'Verve'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022 Verve'
__version__ = '0.0.4'

from json import loads
from requests import get
from .modules.assistants.voice_assistant import VoiceAssistant
from .modules.assistants.generic_assistant import GenericAssistant

__newest__ = loads(get("https://pypi.org/pypi/amino.fix/json").text)["info"]["version"]

if __version__ != __newest__:
    print(f"New version of {__title__} available: {__newest__} (Using {__version__})")
    print("Run \"pip install neural-chat -U\"")
